/*
 * 最常用的ajax方法，获取JSON
 * url：接口地址
 * data：输入参数
 * success：访问成功后要执行的函数
 */
function util_ajaxForJSON(url, data, success){
	
	var _mui = mui;
	
	_mui.ajaxSettings.beforeSend = function(xhr, setting) {
		//beforeSend演示,也可在$.ajax({beforeSend:function(){}})中设置单个Ajax的beforeSend
		console.log('beforeSend:::' + JSON.stringify(setting));
	};
	
	_mui.getJSON(url, data, success);
}

/*
 * 阻止用户操作的ajax方法，获取JSON
 * url：接口地址
 * data：输入参数
 * success：访问成功后要执行的函数，注意要关闭等待框
 */
function util_ajaxForJSONWaiting(url, data, success){
	var _mui = mui,
		plusNativeUI = plus.nativeUI;
	
	plusNativeUI.showWaiting();
	
	_mui.ajaxSettings.beforeSend = function(xhr, setting) {
		//beforeSend演示,也可在$.ajax({beforeSend:function(){}})中设置单个Ajax的beforeSend
		console.log('beforeSend:::' + JSON.stringify(setting));
	};
	
	_mui.ajax(url, {
		data: data,
		dataType:'json',//服务器返回json格式数据
		type:'get',//HTTP请求类型
		timeout:10000,//超时时间设置为10秒；
		success: success,
		error:function(xhr,type,errorThrown){
			//请求失败，首先关闭等待框
			plusNativeUI.closeWaiting();
			//异常处理；			
			plusNativeUI.toast(global_stringObject.wangluoyichang);
		}
	});
}

/*
 * 添加拍卖专场列表
 * dataArray:数据
 * listToAppend：要添加到的列表div
 */
function util_appendAuctionList(dataArray, listToAppend){
	var _document = document,
		createAuctionListHTML = util_createAuctionListHTML;
	if(dataArray instanceof Array){
		for(var i=0, len=dataArray.length; i<len; i++){
			var item = dataArray[i];
			var newElement = _document.createElement("ul");
			newElement.className = "mui-table-view mui-grid-view div1 tappable";
			newElement.dataset.action = "auctionDetail";
			newElement.dataset.id = item.id;
			newElement.innerHTML = createAuctionListHTML(item);
			
			listToAppend.appendChild(newElement);
		}	
	}
	
}

/*
 * 添加拍卖产品列表
 * dataArray:数据
 * listToAppend：要添加到的列表ul
 */
function util_appendAuctoinProductList(dataArray, listToAppend){
	var _document = document,
		createAuctionProductListHTML = util_createAuctionProductListHTML,
		freshTime = util_freshTime;
	for(var i=0, len=dataArray.length; i<len; i++){
		var item = dataArray[i];
		var newElement = _document.createElement("li");
		newElement.className = "mui-table-view-cell mui-media mui-col-xs-6 tappable";
		var dataset = newElement.dataset;
		dataset.action = "auctionProductDetail";
		dataset.id = item.id;
		dataset.startdate = item.startdate;
		
		var startDate = new Date(item.startdate),
			beginDate = new Date(item.begindate);
		
		//预展
		if(startDate < beginDate){
			dataset.enddate = item.begindate;	
			item.dateTag = "距开始";
		}else{
			dataset.enddate = item.enddate;	
			item.dateTag = "距结束";
		}
		newElement.innerHTML = createAuctionProductListHTML(item);
		freshTime(new Date(dataset.startdate), new Date(dataset.enddate), newElement.querySelector("a").lastElementChild);
		listToAppend.appendChild(newElement);
	}
}

/*
 * 添加艺术资讯列表
 * dataArray:数据
 * listToAppend：要添加到的列表ul
 */
function util_appendNewsList(dataArray, listToAppend){
	var _document = document,
		createNewsHTML = util_createNewsHTML;
	
	for(var i=0, len=dataArray.length; i<len; i++){
		var item = dataArray[i];
		var newLi = _document.createElement("li");
		newLi.className = "mui-table-view-cell mui-media mui-media-large tappable";
		newLi.dataset.action = "newsDetail";
		newLi.dataset.id = item.id;
		newLi.innerHTML = createNewsHTML(item);
		listToAppend.appendChild(newLi);
	}
}

/*
 * 添加合作伙伴图片列表
 * dataArray:数据
 * listToAppend：要添加到的列表ul
 */
function util_appendPartnerList(dataArray, listToAppend){
	var _document = document,
		createPartnerHTML = util_createPartnerHTML;
	
	for(var i=0, len=dataArray.length; i<len; i++){
		var item = dataArray[i];
		var newLi = _document.createElement("li");
		newLi.className = "mui-table-view-cell mui-media mui-col-xs-4 tappable";
		newLi.dataset.action = "partner";
		newLi.dataset.url = item.url;
		newLi.innerHTML = createPartnerHTML(item);
		listToAppend.appendChild(newLi);
	}
}

/*
 * 添加商城产品列表
 * dataArray:数据
 * listToAppend：要添加到的列表ul
 */
function util_appendShopProductList(dataArray, listToAppend){
	
	if(dataArray instanceof Array){
		var _document = document,
			createShopProductListHTML = util_createShopProductListHTML;
		for(var i=0, len=dataArray.length; i<len; i++){
			var item = dataArray[i];
			var newElement = _document.createElement("li");
			newElement.className = "mui-table-view-cell mui-media mui-col-xs-6 tappable";
			newElement.dataset.action = "shopProductDetail";
			newElement.dataset.id = item.id;
			newElement.dataset.price = item.price;
			newElement.innerHTML = createShopProductListHTML(item);
			
			//判断是否已售
			if(item.issold){
				util_shopProductListSold(newElement);
			}
			
			listToAppend.appendChild(newElement);
		}
	    
	}
}




/*
 * 根据拍卖订单状态为其设置不同的按钮
 * isReturnApplied:是否已申请退货 true/false
 */
function util_buttonizeAuctionOrder(statusId, order, isReturnApplied){
	
	switch(statusId){
		case global_auctionOrderStatus.daiqueren:
			//确认
			var newDiv = document.createElement("div");
			newDiv.className = "mui-table";
			newDiv.innerHTML = '<div class="mui-table-cell mui-col-xs-12 mui-text-right">'
							 +     '<button type="button" class="mui-btn tappable" data-action="confirm">确认</button>'
							 + '</div>';
			order.appendChild(newDiv);
			break;
		case global_auctionOrderStatus.daifukuan:
			//付款
			var newDiv = document.createElement("div");
			newDiv.className = "mui-table";
			newDiv.innerHTML = '<div class="mui-table-cell mui-col-xs-12 mui-text-right">'
							 +     '<button type="button" class="mui-btn tappable" data-action="pay">付款</button>'
							 + '</div>';
			order.appendChild(newDiv);
			break;
		case global_auctionOrderStatus.daishouhuo:
			//确认收货
			var newDiv = document.createElement("div");
			newDiv.className = "mui-table";
			newDiv.innerHTML = '<div class="mui-table-cell mui-col-xs-12 mui-text-right">'
							 +     '<button type="button" class="mui-btn tappable" data-action="signFor">确认收货</button>'
							 + '</div>';
		 	order.appendChild(newDiv);
			break;		
	}
	
}

/*
 * 根据我参与的拍卖 是否已支付保证金为其设置不同的按钮
 */
function util_buttonizeMyAuction(issdpaid, order){
	
        
	
	switch(issdpaid){
		case true:
			
			var newDiv = document.createElement("div");
			newDiv.className = "mui-table";
			newDiv.innerHTML = '<div class="mui-table-cell mui-col-xs-12 mui-text-right">'
							 +     '<button type="button" class="mui-btn tappable" data-action="reclaim">撤回保证金</button>'
							 + '</div>';
			order.appendChild(newDiv);
			break;
		case false:
			
			break;

	}
	
}

/*
 * 根据订单状态为其设置不同的按钮
 * isReturnApplied:是否已申请退货 true/false
 */
function util_buttonizeOrder(statusId, order, isReturnApplied){
	
	switch(statusId){
		case global_orderStatus.daifukuan:
			//付款 取消
			var newDiv = document.createElement("div");
			newDiv.className = "mui-table";
			newDiv.innerHTML = '<div class="mui-table-cell mui-col-xs-12 mui-text-right">'
							 +     '<button type="button" class="mui-btn tappable" data-action="pay">付款</button>&nbsp'
							 +     '<button type="button" class="mui-btn mui-btn-danger mui-btn-outlined tappable" data-action="cancel">取消</button>'
							 + '</div>';
			order.appendChild(newDiv);
			break;
		case global_orderStatus.yifukuan:
			var newDiv = document.createElement("div");
			var newDivInnerHTML;
			if(isReturnApplied){
				newDivInnerHTML = '<div class="mui-table-cell mui-col-xs-12 mui-text-right">'
								+     '<button type="button" class="mui-btn">退款处理中</button>'
								+ '</div>';
			}else{
				newDivInnerHTML = '<div class="mui-table-cell mui-col-xs-12 mui-text-right">'
								+     '<button type="button" class="mui-btn tappable" data-action="return">退款</button>'
								+ '</div>';
			}
			
			newDiv.className = "mui-table";
			newDiv.innerHTML = newDivInnerHTML;
		 	order.appendChild(newDiv);
			break;
		case global_orderStatus.daishouhuo:
			//确认收货
			var newDiv = document.createElement("div");
			var newDivInnerHTML;
			if(isReturnApplied){
				newDivInnerHTML = '<div class="mui-table-cell mui-col-xs-12 mui-text-right">'
				                +     '<button type="button" class="mui-btn tappable" data-action="signFor">确认收货</button>'
								+     '<button type="button" class="mui-btn">退款处理中</button>'
								+ '</div>';
			}else{
				newDivInnerHTML = '<div class="mui-table-cell mui-col-xs-12 mui-text-right">'
				                +     '<button type="button" class="mui-btn tappable" data-action="signFor">确认收货</button>'
								+     '<button type="button" class="mui-btn tappable" data-action="return">退款</button>'
								+ '</div>';
			}
			
			newDiv.className = "mui-table";
			newDiv.innerHTML = newDivInnerHTML;
		
		 	order.appendChild(newDiv);
			break;
		
		case global_orderStatus.yiwancheng:
			//申请退货
			var newDiv = document.createElement("div");
			var newDivInnerHTML;
			if(isReturnApplied){
				newDivInnerHTML = '<div class="mui-table-cell mui-col-xs-12 mui-text-right">'
								+     '<button type="button" class="mui-btn">退货处理中</button>'
								+ '</div>';
			}else{
				newDivInnerHTML = '<div class="mui-table-cell mui-col-xs-12 mui-text-right">'
								+     '<button type="button" class="mui-btn tappable" data-action="return">申请售后</button>'
								+ '</div>';
			}
			
			newDiv.className = "mui-table";
			newDiv.innerHTML = newDivInnerHTML;
		 	order.appendChild(newDiv);
			break;
	}
	
}

/*
 * 去掉逗号分隔的数字中的逗号
 * commaSeparatedNumber：逗号分隔的数字
 */
function util_convertCommaSeparatedNumberToNumber(commaSeparatedNumber){
    var copy = commaSeparatedNumber,
        before, //用于存逗号前的值
        after; //用于存逗号后面的值
        
    
    while(copy.indexOf(",") != -1){
        var markIndex = copy.indexOf(","); 
        before = copy.substring(0, markIndex);
        after = copy.substring(markIndex + 1);
        copy = before + after;
    }
    
    return copy;
}

/*
 * 拼接ajax URL
 */
function createAjaxURL(name, method){
	return ('http://' + global_publicNetwork + '/api/' + name + '/' + method);
}

/*
 * 拼接ajax URL pc
 */
function util_createPCAjaxURL(method){
	return ('http://' + global_pcIP + '/' + method + '.ashx');
}



/*
 * 艺术家列表
 */
function util_createArtistListHTML(dataObj){
	var html = '<a>'
			 +     '<img class="mui-media-object" src="' + dataObj.src + '">'
			 +     '<div class="mui-media-body">' + dataObj.name + '</div>'
			 +     '<div class="mui-media-body">' + dataObj.info + '</div>'
			 +     '<div class="mui-media-body">作品数量 : <span class="price">' + dataObj.workcount + '</span> 访问人数 : <span class="price">' + dataObj.visitorcount + '</span></div>'
			 + '</a>';
	        
	return html;
}

/*
 * 专场拍卖列表
 */
function util_createAuctionListHTML(dataObj){
	var html = '<li class="mui-table-view-cell mui-media mui-col-xs-12">'
			 +     '<a ><img class="mui-media-object" src="' + dataObj.src + '"></a>'
			 + '</li>'
			 + '<li class="mui-table-view-cell mui-media mui-col-xs-12">'
			 +     '<a >'
			 +         '<div class="mui-media-body" id="auction">' + dataObj.title + '</div>'
			 +         '<div class="mui-media-body" id="auction_person"><span class="price" >' + dataObj.persons + '</span>人参拍|<span class="price">' + dataObj.works + '</span>件拍品</div>'
			 +         '<div class="mui-media-body" id="auction_time">拍卖时间：' + dataObj.startdate + ' 至 ' + dataObj.enddate + '</div>'
			 +     '</a>'
			 + '</li>';
			             
	return html;
}

/*
 * 我的拍卖订单列表
 */
function util_createAuctionOrderHTML(dataObj){
	var html = '<div class="mui-table">'
			 +     '<div class="mui-table-cell mui-col-xs-8">'
			 + 	       '<h5 class="mui-ellipsis">订单编号： ' + dataObj.orderno + '</h5>'
			 +     '</div>'
			 +     '<div class="mui-table-cell mui-col-xs-4 mui-text-right">'
			 +         '<h5 class="mui-ellipsis">' + dataObj.status + '</h5>'
			 +     '</div>'
			 + '</div>'
			 + '<ul class="mui-table-view">'
			 +     util_createAuctionProductHTML(dataObj.products)
			 + '</ul>'
			 + '<div class="mui-table">'
			 +     '<div class="mui-table-cell mui-col-xs-12">'
			 +         '<h5 class="mui-text-right" style="float: right; color: #000000; padding-top: 10px; padding-bottom: 10px;">竞拍金额：¥<span class="price">' + dataObj.bidprice + '</span></h5>'
			 +         '<h5 class="mui-text-left" style="color: #000000; padding-top: 10px; padding-bottom: 10px;">保证金：¥<span class="price">' + dataObj.securitydeposit + '</span></h5>'
			 +     '</div>'
			 + '</div>';	        
                	
	return html;
}



function util_createAuctionProductListHTML(dataObj){
	
	var html = '<a id="line_border">'
			 +     '<img class="mui-media-object" id="auctionPic" src="' + dataObj.src + '">'
			 +     '<div class="mui-media-body">' + dataObj.title + '</div>'
			 +     '<div class="mui-media-body price">￥' + dataObj.price + '</div>'
			 +     '<div class="mui-media-body unimportant">出价次数：' + dataObj.bids + '次</div>'
			 +     '<div class="mui-media-body">' + dataObj.dateTag + ':</div>'
			 +     '<div class="mui-media-body"></div>'
			 + '</a>';
	        
	return html;
}

/*
 * 我参与的拍卖列表
 */
function util_createMyAuctionHTML(dataObj){
	var html = '<div class="mui-table">'
			 +     '<div class="mui-table-cell mui-col-xs-8">'
			 + 	       '<h5 class="mui-ellipsis"></h5>'
			 +     '</div>'
			 +     '<div class="mui-table-cell mui-col-xs-4 mui-text-right">'
			 +         '<h5 class="mui-ellipsis">' + dataObj.bidsuccess + '</h5>'
			 +     '</div>'
			 + '</div>'
			 + '<ul class="mui-table-view">'
			 +     util_createMyAuctionProductHTML(dataObj)
			 + '</ul>'
			 + '<div class="mui-table">'
			 +     '<div class="mui-table-cell mui-col-xs-12">'
			 +         '<h5 class="mui-text-right" style="float: right; color: #000000; padding-top: 10px; padding-bottom: 10px;">保证金状态：<span>' + dataObj.sdpaid + '</span></h5>'
			 +         '<h5 class="mui-text-left" style="color: #000000; padding-top: 10px; padding-bottom: 10px;">保证金：¥<span class="price">' + dataObj.securitydeposit + '</span></h5>'
			 +     '</div>'
			 + '</div>';	
		
            
                	
	return html;
}

/*
 * 我参与的拍卖 产品
 */
function util_createMyAuctionProductHTML(data){
	
	var html = '<li class="mui-table-view-cell mui-media mui-media-large tappable" style="padding-left: 9px; padding-right: 9px;" data-productid="' + data.productid + '" data-action="auctionProductDetail">'
			 +     '<a>'
			 +         '<img class="mui-media-object mui-pull-left " src="' + data.src + '">'
			 +         '<div class="mui-media-body">'					   
			 +             '<p class="mui-ellipsis" style="color: #000000;">' + data.tilte + '</p>'					   
			 +         '</div>'
			 +     '</a>'
			 + '</li>';
	
	return html;
}

/*
 * 艺术资讯列表
 */
function util_createNewsHTML(dataObj){
	var html = '<a>'
			 +     '<img class="mui-media-object mui-pull-left " src="' + dataObj.src + '">'
			 +     '<div class="mui-media-body" style="white-space: normal;">' 
			 +         '<span id="smriti">'+dataObj.title+'</span>'
			 +         '<p class="mui-ellipsis price" id="personP">' + dataObj.type + '</p>'
			 +         '<p class="mui-ellipsis">' + dataObj.inputtime + '</p>'
			 +         '<p class="mui-ellipsis">' + dataObj.summary + '</p>'
			 +     '</div>'
			 + '</a>';
			
	return html;
}


/*
 * 合作伙伴图片列表
 */
function util_createPartnerHTML(dataObj){
	var html = '<a>'
			 +     '<img class="mui-media-object" src="' + dataObj.src + '">'			 
			 + '</a>';
			 
	return html;
}

/*
 * 加入购物车
 * productId: 加入的产品id
 * number： 加入的数量
 * isBuyNow如果为true, 则立即购买此产品
 */
function util_addToCart(productId, number, isBuyNow){
	var _localStorage = localStorage,
		_mui = mui,
		ajaxObjectOrder = global_ajaxObject.order;
	
	var url = createAjaxURL(ajaxObjectOrder.name, ajaxObjectOrder.method_addintocart);
	var loc_cartId = _localStorage.getItem("loc_cartId"); 
	if(typeof loc_cartId !== "string" || loc_cartId === ""){
		var guid = new GUID();
		_localStorage.setItem("loc_cartId", guid.newGUID());　　					
	}

	//属性的顺序决定了最终url里参数的顺序
	var data = {	
		cartid: _localStorage.getItem("loc_cartId"),
		number: number, 
		productid: productId,										
		username: _localStorage.getItem("loc_userId")
	};
	MD5Data(data);
	
	var buyThisProduct = function(){
		_localStorage.setItem("loc_buyNow", true);
		_localStorage.setItem("loc_buyNowProductId", productId);
		
		_mui.openWindow({
			id: "cart_buy_parent.html",
			url: "cart_buy_parent.html",
			styles: {
				popGesture: "close"
			},
			show: {
				aniShow: "pop-in",
				autoShow: true
			},
			waiting: {
				autoShow: false
			}
		});	
	};
	
	var success = function(response){
		switch(response.result){
			case 0:
				_mui.toast("添加成功");
				
				_mui.fire(plus.webview.getWebviewById("product_detail_parent.html"), 'ce_cartcount', null);
				if(isBuyNow){
					buyThisProduct();
				}
				break;
			case 1:
				_mui.toast("已添加");
				if(isBuyNow){
					buyThisProduct();
				}
				break;
			case 2:
				_mui.toast("添加失败");
				break;
			case 3:
				_mui.toast("当前禁止销售此商品");
				break;
		}
	};
	
	util_ajaxForJSON(url, data, success);
}

/*
 * (bool)display:是否展示返回箭头
 * (element)arrow:箭头
 */
function util_changeArrowHandler(display, arrow){	
	if(display){
		arrow.style.display = "block";
	}else{
		arrow.style.display = "none";
	}
}

/*
 * 改变标题
 * (string)text:文字
 * (element)title:标题元素
 */
function util_changeTitleHandler(text, title){
	title.innerHTML = text;
}

/*
 * 我的订单列表
 */
function util_createOrderHTML(dataObj){
	var html = '<div class="mui-table">'
			 +     '<div class="mui-table-cell mui-col-xs-8">'
			 + 	       '<h5 class="mui-ellipsis">订单编号： ' + dataObj.orderno + '</h5>'
			 +     '</div>'
			 +     '<div class="mui-table-cell mui-col-xs-4 mui-text-right">'
			 +         '<h5 class="mui-ellipsis">' + dataObj.status + '</h5>'
			 +     '</div>'
			 + '</div>'
			 + '<ul class="mui-table-view">'
			 +     util_createProductHTML(dataObj.products)
			 + '</ul>'
			 + '<div class="mui-table">'
			 +     '<div class="mui-table-cell mui-col-xs-12">'
			 +         '<h5 class="mui-text-right" style="color: #000000; padding-top: 10px; padding-bottom: 10px;">总金额：¥<span class="price">' + dataObj.price + '</span></h5>'
			 +     '</div>'
			 + '</div>';
                	
	return html;
}







/*
 * 订单列表里的产品列表
 */
function util_createProductHTML(dataArray){
	var html = '';
	if(dataArray instanceof Array){
		for(var i=0, len=dataArray.length; i<len; i++){
			var item = dataArray[i];
			var liHtml = '<li class="mui-table-view-cell mui-media mui-media-large" style="padding-left: 9px; padding-right: 9px;">'
					   +     '<a>'
					   +         '<img class="mui-media-object mui-pull-left " src="' + item.src + '">'
					   +         '<div class="mui-media-body">'
					   +             '<p class="mui-ellipsis price" style="float: right;">' + item.price + '</p>'
					   +             '<p class="mui-ellipsis" style="color: #000000;">' + item.title + '</p>'
					   +             '<p class="mui-ellipsis" style="float: right;">x ' + item.number + '</p>'
					   //+             '<p class="mui-ellipsis">编号：' + item.no + '</p>'
					   +         '</div>'
					   +     '</a>'
					   + '</li>';
							
			html += liHtml;
		}
	}
	
	return html;
}



/*
 * 拍卖订单列表里的产品列表
 */
function util_createAuctionProductHTML(dataArray){
	var html = '';
	if(dataArray instanceof Array){
		for(var i=0, len=dataArray.length; i<len; i++){
			var item = dataArray[i];
			var liHtml = '<li class="mui-table-view-cell mui-media mui-media-large" style="padding-left: 9px; padding-right: 9px;">'
					   +     '<a>'
					   +         '<img class="mui-media-object mui-pull-left " src="' + item.src + '">'
					   +         '<div class="mui-media-body">'					   
					   +             '<p class="mui-ellipsis" style="color: #000000;">' + item.title + '</p>'					   
					   +         '</div>'
					   +     '</a>'
					   + '</li>';
							
			html += liHtml;
		}
	}
	
	return html;
}



/*
 * 商城列表
 */
function util_createShopProductListHTML(dataObj){
	var html = '<a>'
			 +     '<img class="mui-media-object" src="' + dataObj.src + '">'
			 +     '<div class="mui-media-body" id="home_fontSize">' + dataObj.title + '</div>'
			 +     '<div class="mui-media-body price" id="home_price">￥' + dataObj.price + '</div>'
			 + '</a>';
	        
	return html;
}

/*
 * 站内信列表
 */
function util_createSiteLetterListHTML(dataObj){
	var html = '<div class="mui-table">'
	         +     '<div class="mui-media-body ' + dataObj.isreaded + '">' + dataObj.title + '</div>'
	         +     '<div class="mui-table-cell mui-col-xs-2 mui-text-right">'
	         +         '<span class="mui-h5">' + dataObj.time + '</span>'
	         +     '</div>'
	         + '</div>';
			
	return html;
}

/*
 * 为轮播图片的topDiv添加innerHTML
 * topDiv:轮播图片的topDiv
 * bottomDiv: 轮播图片的bottomDiv
 * srcs:正常的图片地址(不包括额外添加的第一张和最后一张)
 */
function util_createSlidingImgHTML(topDiv, bottomDiv, srcs){ 
	if(srcs instanceof Array){
		var _document = document;
		
		
		for(var i=0, len=srcs.length; i<len; i++){
			//添加正常图片
			var imgDiv = _document.createElement("div");
			imgDiv.className = "mui-slider-item";
			imgDiv.innerHTML = '<a><img src="' + srcs[i] + '" data-preview-src="" data-preview-group="10"></a>';
			topDiv.appendChild(imgDiv);
			
			//添加指示点
			var indicatorDiv = _document.createElement("div");
			if(i == 0){
				indicatorDiv.className = "mui-indicator mui-active";
			}else{
				indicatorDiv.className = "mui-indicator";
			}
			bottomDiv.appendChild(indicatorDiv);
			
		}
		
		//补充第一张图片和最后一张图片
		//额外增加的一个节点(循环轮播：第一个节点是最后一张轮播)
		var imgDivAsFirst = _document.createElement("div");
		imgDivAsFirst.className = "mui-slider-item mui-slider-item-duplicate"; 
		imgDivAsFirst.innerHTML = '<a><img src="' + srcs[srcs.length - 1] + '"></a>';
		topDiv.insertBefore(imgDivAsFirst, topDiv.firstChild);
		
		//额外增加的一个节点(循环轮播：最后一个节点是第一张轮播)
		var imgDivAsLast = _document.createElement("div");
		imgDivAsLast.className = "mui-slider-item mui-slider-item-duplicate"; 
		imgDivAsLast.innerHTML = '<a><img src="' + srcs[0] + '"></a>';
		topDiv.appendChild(imgDivAsLast);
	}
}

/*
 * 发送短信倒计时
 * button: 按钮
 * timeController: 时间控制器对象,包含三个属性
 *                              intervalId: 定时器id
 *                                 max: 最大时间
 *                                 min: 最小时间
 */
function util_decrementNumber(button, timeController) {											
	timeController.max--;
	button.innerHTML = timeController.max;
	//if the max has been reached, cancel all pending executions
	if (timeController.max == timeController.min) {
		clearInterval(timeController.intervalId);		
		button.dataset.status = "ready";		
		button.innerHTML = "获取验证码";
	}
}

/*
 * 根据dataElement是否含有子元素来判断是否展示noInfo
 */
function util_displayNoInfo(noInfo, dataElement){
	var noInfoStyle = noInfo.style;
	if(dataElement.childElementCount > 0){
		noInfoStyle.display = "none";
	}else{
		noInfoStyle.display = "block";
	}
}

/*
 * 制作轮播图
 * slider:打算做成轮播的div(<div id="slider" class="mui-slider" >)
 * srcs:图片地址数组
 * 返回HTML,上半部分为图片,下半部分为指示点
 */
function util_displaySlider(slider, srcs){
	//slider.innerHTML = "";
	var _document = document;
	var html = '';
	//topDiv存放图片
	var topDiv = _document.createElement("div");
	topDiv.className = "mui-slider-group mui-slider-loop";
	
	//bottomDiv存放指示点
	var bottomDiv = _document.createElement("div");
	bottomDiv.className = "mui-slider-indicator";
	
	util_createSlidingImgHTML(topDiv, bottomDiv, srcs);	
	
	slider.appendChild(topDiv);
	slider.appendChild(bottomDiv);
}



/*
 * 元素dataset上保存有startdate和enddate，需要用其生成一个Date对象，加上1秒，再保存回dataset中，接着调用util_freshTime
 * elementData: 数据保存的元素
 * elementDisplay： 展示时间的元素
 * 有时候elementData==elementDisplay
 */
function util_elementCountdown(elementData, elementDisplay){
	var dataset = elementData.dataset;
	var startDate = new Date(dataset.startdate);
	
	startDate.setSeconds(startDate.getSeconds() + 1);
	dataset.startdate = startDate.toUTCString();
	util_freshTime(new Date(dataset.startdate), new Date(dataset.enddate), elementDisplay);
}

/*
 * 根据nowtime和endtime把倒计时展示到displayElement
 * nowtime:当前时间
 * endtime:结束时间
 * displayElement:展示元素
 */
function util_freshTime(nowtime, endtime, displayElement){
	if(nowtime == null){
		nowtime = new Date();
	}
	
	//"2016/7/15,12:20:12"
	var lefttime=parseInt((endtime.getTime()-nowtime.getTime())/1000);
    if(lefttime<=0){
        displayElement.innerHTML="已结束";
        //clearInterval(freshInternal);
    }else{
    	
    	var d=parseInt(lefttime/3600/24),
        	h=parseInt((lefttime/3600)%24),
        	m=parseInt((lefttime/60)%60),
        	s=parseInt(lefttime%60);
        	
    	displayElement.innerHTML = '<span class="price">' + d + '</span>天<span class="price">' + h + '</span>时<span class="price">' + m + '</span>分<span class="price">' + s + '</span>秒';
    	
    } 
}

/*
 * 获取版权信息
 */
function util_getCopyright(div){
	var ajaxObject = global_ajaxObject.news;
	var url = createAjaxURL(ajaxObject.name, ajaxObject.method_getcopyright);
	var data = {
		username: localStorage.getItem("loc_userId") 
	};
	MD5Data(data);
	var success = function(response) {			 		
		div.innerHTML = response.content;
		
	};
	util_ajaxForJSON(url, data, success);
}

/*
 * 获取轮播图
 * divSliderId: 轮播最外层的div 的 id
 * divSlidingPics: 上半部分（图片部分）的div
 * divIndicator: 下半部分（指示点部分）的div
 * divLastPic: 最后一个图片节点
 * imgFirstPic: 第一个图片节点里的图片
 * imgLastPic: 最后一个图片节点里的图片
 */
function util_getSlidingPictures(divSliderId, divSlidingPics, divIndicator, divLastPic, imgFirstPic, imgLastPic){
	var _mui = mui;
	var _document = document;
	var ajaxNews = global_ajaxObject.news;
	var url = createAjaxURL(ajaxNews.name, ajaxNews.method_getslidingpictures);

	//属性的顺序决定了最终url里参数的顺序
	var data = {			
		username: localStorage.getItem("loc_userId")
	};
	MD5Data(data);
	
	var success = function(response) {
		if(response instanceof Array){
			var picNum = response.length;
			if(picNum > 0){
				//加载图片
				var srcFirstPic = "",
					windowFirstPic = "",
					idFirstPic = "",
					srcLastPic = "",
					windowLastPic = "",
					idLastPic = "";
					
				for(var i=0, len=picNum; i<len; i++){
					var currentItem = response[i];
					if(i == 0){
						srcFirstPic = currentItem.src;
						windowFirstPic = currentItem.url;
						idFirstPic = currentItem.id;
					}
					
					if(i == (len - 1)){
						srcLastPic = currentItem.src;
						windowLastPic = currentItem.url;
						idLastPic = currentItem.id;
					}
					
					var div = _document.createElement("div"),
						a = _document.createElement("a"),
						img = _document.createElement("img"),
						imgDataset = img.dataset;
						
					img.src = currentItem.src; 
					img.classList.add("tappable");
					imgDataset.action = "openWindow";
					imgDataset.window = currentItem.url;
					imgDataset.id = currentItem.id;
					
					
					a.appendChild(img);
					div.appendChild(a);
					div.className = "mui-slider-item";
					divSlidingPics.insertBefore(div, divLastPic);
				}
		
				
				imgFirstPic.src = srcLastPic;
				imgFirstPic.classList.add("tappable");
				var imgFirstPicDataset = imgFirstPic.dataset;
				imgFirstPicDataset.action = "openWindow";
				imgFirstPicDataset.window = windowLastPic;
				imgFirstPicDataset.id = idLastPic;
				
				imgLastPic.src = srcFirstPic;
				imgLastPic.classList.add("tappable");
				var imgLastPicDataset = imgLastPic.dataset;
				imgLastPicDataset.action = "openWindow";
				imgLastPicDataset.window = windowFirstPic;
				imgLastPicDataset.id = idFirstPic;
				
				//加载指示点（只用当返回的图片数大于2才会加载，因为本身已经有两个了）
				if(picNum > 2){
					for(var i=0, len=picNum-2; i<len; i++){
						var newDivIndicator = _document.createElement("div");
						newDivIndicator.className = "mui-indicator";
						divIndicator.appendChild(newDivIndicator);
					}
				}
			}
		}
		
		_mui("#" + divSliderId).slider({
			interval: 5000
		});
		
	};
	
	_mui.ajaxSettings.beforeSend = function(xhr, setting) {
		//beforeSend演示,也可在$.ajax({beforeSend:function(){}})中设置单个Ajax的beforeSend
		console.log('beforeSend:::' + JSON.stringify(setting));
	};
	
	_mui.getJSON(url, data, success);
}


/*
 * 通过检查父节点是否含有某个css class
 * child:子节点
 * class：父节点应包含的css class
 * 如果找到了满足条件的父节点就返回该父节点，否则返回空
 */

function util_getWrapperByClass(child, wrapperClass){
	
	var documentBody = document.body;
	var documentBodyParentNode = documentBody.ParentNode;
	var wrapper = child;
								
	while(!wrapper.classList.contains(wrapperClass)){
        if(wrapper === documentBody || wrapper === documentBodyParentNode){
            break;
        }
                     
        var wrapperParentNode = wrapper.parentNode;
        if(wrapperParentNode){
            wrapper = wrapperParentNode;    
        }else{
            break;
        }
        
        if(wrapper === documentBody || wrapper === documentBodyParentNode){
            break;
        }
    }
	
	if(wrapper.classList.contains(wrapperClass)){
		return wrapper;
	}else{
		return null;
	}
	
}

/*
 * 通过检查父节点nodeName
 * child:子节点
 * nodeName：父节点nodeName
 * 如果找到了满足条件的父节点就返回该父节点，否则返回空
 */

function util_getWrapperByNodeName(child, nodeName){
	
	var documentBody = document.body;
	var documentBodyParentNode = documentBody.ParentNode;
	var wrapper = child;
								
	while(wrapper.nodeName.toLowerCase() !== nodeName){
        if(wrapper === documentBody || wrapper === documentBodyParentNode){
            break;
        }
                     
        var wrapperParentNode = wrapper.parentNode;
        if(wrapperParentNode){
            wrapper = wrapperParentNode;    
        }else{
            break;
        }
        
        if(wrapper === documentBody || wrapper === documentBodyParentNode){
            break;
        }
    }
	
	if(wrapper.nodeName.toLowerCase() === nodeName){
		return wrapper;
	}else{
		return null;
	}
	
}



/*
 * 功能：生成一个GUID码，其中GUID以14个以下的日期时间及18个以上的16进制随机数组成，GUID存在一定的重复概率，但重复概率极低，理论上重复概率为每10ms有1/(16^18)，即16的18次方分之1，重复概率低至可忽略不计
 * 免责声明：此代码为作者学习专用，如在使用者在使用过程中因代码问题造成的损失，与作者没有任何关系
 * 日期：2014年9月4日
 * 作者：wyc
 */
 
  
function GUID() {
  this.date = new Date();
 
  /* 判断是否初始化过，如果初始化过以下代码，则以下代码将不再执行，实际中只执行一次 */
  if (typeof this.newGUID != 'function') {
     
    /* 生成GUID码 */
    GUID.prototype.newGUID = function() {
      this.date = new Date();
      var guidStr = '';
        sexadecimalDate = this.hexadecimal(this.getGUIDDate(), 16);
        sexadecimalTime = this.hexadecimal(this.getGUIDTime(), 16);
      for (var i = 0; i < 9; i++) {
        guidStr += Math.floor(Math.random()*16).toString(16);
      }
      guidStr += sexadecimalDate;
      guidStr += sexadecimalTime;
      while(guidStr.length < 32) {
        guidStr += Math.floor(Math.random()*16).toString(16);
      }
      return this.formatGUID(guidStr);
    }
 
    /*
     * 功能：获取当前日期的GUID格式，即8位数的日期：19700101
     * 返回值：返回GUID日期格式的字条串
     */
    GUID.prototype.getGUIDDate = function() {
      return this.date.getFullYear() + this.addZero(this.date.getMonth() + 1) + this.addZero(this.date.getDay());
    }
 
    /*
     * 功能：获取当前时间的GUID格式，即8位数的时间，包括毫秒，毫秒为2位数：12300933
     * 返回值：返回GUID日期格式的字条串
     */
    GUID.prototype.getGUIDTime = function() {
      return this.addZero(this.date.getHours()) + this.addZero(this.date.getMinutes()) + this.addZero(this.date.getSeconds()) + this.addZero( parseInt(this.date.getMilliseconds() / 10 ));
    }
 
    /*
    * 功能: 为一位数的正整数前面添加0，如果是可以转成非NaN数字的字符串也可以实现
     * 参数: 参数表示准备再前面添加0的数字或可以转换成数字的字符串
     * 返回值: 如果符合条件，返回添加0后的字条串类型，否则返回自身的字符串
     */
    GUID.prototype.addZero = function(num) {
      if (Number(num).toString() != 'NaN' && num >= 0 && num < 10) {
        return '0' + Math.floor(num);
      } else {
        return num.toString();
      }
    }
 
    /* 
     * 功能：将y进制的数值，转换为x进制的数值
     * 参数：第1个参数表示欲转换的数值；第2个参数表示欲转换的进制；第3个参数可选，表示当前的进制数，如不写则为10
     * 返回值：返回转换后的字符串
     */
    GUID.prototype.hexadecimal = function(num, x, y) {
      if (y != undefined) {
        return parseInt(num.toString(), y).toString(x);
      } else {
        return parseInt(num.toString()).toString(x);
      }
    }
 
    /*
     * 功能：格式化32位的字符串为GUID模式的字符串
     * 参数：第1个参数表示32位的字符串
     * 返回值：标准GUID格式的字符串
     */
    GUID.prototype.formatGUID = function(guidStr) {
      var str1 = guidStr.slice(0, 8) + '-',
        str2 = guidStr.slice(8, 12) + '-',
        str3 = guidStr.slice(12, 16) + '-',
        str4 = guidStr.slice(16, 20) + '-',
        str5 = guidStr.slice(20);
      return str1 + str2 + str3 + str4 + str5;
    }
  }
}

function util_openWindow(url){
	mui.openWindow({
		id: url,
		url: url,
		styles: {
			popGesture: "close"
		},
		show: {
			aniShow: "pop-in",
			autoShow: true
		},
		waiting: {
			autoShow: false
		}
	});
}

/*
 * 将imgs(集合)中的<img>都加上data-preview-src和data-preview-group
 * group:第几组
 */
function util_previewize(imgs, group){
	for(var i=0, len=imgs.length; i<len; i++){
		var item = imgs[i];
		item.setAttribute("data-preview-src", "");
		item.setAttribute("data-preview-group", group);		
	}
}

/*
 * 商城产品列表，如果某产品已售
 * product:此处是个li
 */
function util_shopProductListSold(product){
	var newDiv = document.createElement("div");
	newDiv.className = "le-shop-product-list-sold";
	newDiv.innerHTML = '<img src="images/sold.png" />';
	product.insertBefore(newDiv, product.lastElementChild);
}



var rotateLeft = function(lValue, iShiftBits) {
	return (lValue << iShiftBits) | (lValue >>> (32 - iShiftBits));
}
var addUnsigned = function(lX, lY) {
	var lX4, lY4, lX8, lY8, lResult;
	lX8 = (lX & 0x80000000);
	lY8 = (lY & 0x80000000);
	lX4 = (lX & 0x40000000);
	lY4 = (lY & 0x40000000);
	lResult = (lX & 0x3FFFFFFF) + (lY & 0x3FFFFFFF);
	if (lX4 & lY4) return (lResult ^ 0x80000000 ^ lX8 ^ lY8);
	if (lX4 | lY4) {
		if (lResult & 0x40000000) return (lResult ^ 0xC0000000 ^ lX8 ^ lY8);
		else return (lResult ^ 0x40000000 ^ lX8 ^ lY8);
	} else {
		return (lResult ^ lX8 ^ lY8);
	}
}
var F = function(x, y, z) {
	return (x & y) | ((~ x) & z);
}
var G = function(x, y, z) {
	return (x & z) | (y & (~ z));
}
var H = function(x, y, z) {
	return (x ^ y ^ z);
}
var I = function(x, y, z) {
	return (y ^ (x | (~ z)));
}
var FF = function(a, b, c, d, x, s, ac) {
	a = addUnsigned(a, addUnsigned(addUnsigned(F(b, c, d), x), ac));
	return addUnsigned(rotateLeft(a, s), b);
};
var GG = function(a, b, c, d, x, s, ac) {
	a = addUnsigned(a, addUnsigned(addUnsigned(G(b, c, d), x), ac));
	return addUnsigned(rotateLeft(a, s), b);
};
var HH = function(a, b, c, d, x, s, ac) {
	a = addUnsigned(a, addUnsigned(addUnsigned(H(b, c, d), x), ac));
	return addUnsigned(rotateLeft(a, s), b);
};
var II = function(a, b, c, d, x, s, ac) {
	a = addUnsigned(a, addUnsigned(addUnsigned(I(b, c, d), x), ac));
	return addUnsigned(rotateLeft(a, s), b);
};
var convertToWordArray = function(string) {
	var lWordCount;
	var lMessageLength = string.length;
	var lNumberOfWordsTempOne = lMessageLength + 8;
	var lNumberOfWordsTempTwo = (lNumberOfWordsTempOne - (lNumberOfWordsTempOne % 64)) / 64;
	var lNumberOfWords = (lNumberOfWordsTempTwo + 1) * 16;
	var lWordArray = Array(lNumberOfWords - 1);
	var lBytePosition = 0;
	var lByteCount = 0;
	while (lByteCount < lMessageLength) {
		lWordCount = (lByteCount - (lByteCount % 4)) / 4;
		lBytePosition = (lByteCount % 4) * 8;
		lWordArray[lWordCount] = (lWordArray[lWordCount] | (string.charCodeAt(lByteCount) << lBytePosition));
		lByteCount++;
	}
	lWordCount = (lByteCount - (lByteCount % 4)) / 4;
	lBytePosition = (lByteCount % 4) * 8;
	lWordArray[lWordCount] = lWordArray[lWordCount] | (0x80 << lBytePosition);
	lWordArray[lNumberOfWords - 2] = lMessageLength << 3;
	lWordArray[lNumberOfWords - 1] = lMessageLength >>> 29;
	return lWordArray;
};
var wordToHex = function(lValue) {
	var WordToHexValue = "", WordToHexValueTemp = "", lByte, lCount;
	for (lCount = 0; lCount <= 3; lCount++) {
		lByte = (lValue >>> (lCount * 8)) & 255;
		WordToHexValueTemp = "0" + lByte.toString(16);
		WordToHexValue = WordToHexValue + WordToHexValueTemp.substr(WordToHexValueTemp.length - 2, 2);
	}
	return WordToHexValue;
};
var uTF8Encode = function(string) {
	string = string.replace(/\x0d\x0a/g, "\x0a");
	var output = "";
	for (var n = 0; n < string.length; n++) {
		var c = string.charCodeAt(n);
		if (c < 128) {
			output += String.fromCharCode(c);
		} else if ((c > 127) && (c < 2048)) {
			output += String.fromCharCode((c >> 6) | 192);
			output += String.fromCharCode((c & 63) | 128);
		} else {
			output += String.fromCharCode((c >> 12) | 224);
			output += String.fromCharCode(((c >> 6) & 63) | 128);
			output += String.fromCharCode((c & 63) | 128);
		}
	}
	return output;
};

var MD5 = function (string) {
  
    var x = Array();
	var k, AA, BB, CC, DD, a, b, c, d;
	var S11=7, S12=12, S13=17, S14=22;
	var S21=5, S22=9 , S23=14, S24=20;
	var S31=4, S32=11, S33=16, S34=23;
	var S41=6, S42=10, S43=15, S44=21;
	string = uTF8Encode(string);
	x = convertToWordArray(string);
	a = 0x67452301; b = 0xEFCDAB89; c = 0x98BADCFE; d = 0x10325476;
	for (k = 0; k < x.length; k += 16) {
		AA = a; BB = b; CC = c; DD = d;
		a = FF(a, b, c, d, x[k+0],  S11, 0xD76AA478);
		d = FF(d, a, b, c, x[k+1],  S12, 0xE8C7B756);
		c = FF(c, d, a, b, x[k+2],  S13, 0x242070DB);
		b = FF(b, c, d, a, x[k+3],  S14, 0xC1BDCEEE);
		a = FF(a, b, c, d, x[k+4],  S11, 0xF57C0FAF);
		d = FF(d, a, b, c, x[k+5],  S12, 0x4787C62A);
		c = FF(c, d, a, b, x[k+6],  S13, 0xA8304613);
		b = FF(b, c, d, a, x[k+7],  S14, 0xFD469501);
		a = FF(a, b, c, d, x[k+8],  S11, 0x698098D8);
		d = FF(d, a, b, c, x[k+9],  S12, 0x8B44F7AF);
		c = FF(c, d, a, b, x[k+10], S13, 0xFFFF5BB1);
		b = FF(b, c, d, a, x[k+11], S14, 0x895CD7BE);
		a = FF(a, b, c, d, x[k+12], S11, 0x6B901122);
		d = FF(d, a, b, c, x[k+13], S12, 0xFD987193);
		c = FF(c, d, a, b, x[k+14], S13, 0xA679438E);
		b = FF(b, c, d, a, x[k+15], S14, 0x49B40821);
		a = GG(a, b, c, d, x[k+1],  S21, 0xF61E2562);
		d = GG(d, a, b, c, x[k+6],  S22, 0xC040B340);
		c = GG(c, d, a, b, x[k+11], S23, 0x265E5A51);
		b = GG(b, c, d, a, x[k+0],  S24, 0xE9B6C7AA);
		a = GG(a, b, c, d, x[k+5],  S21, 0xD62F105D);
		d = GG(d, a, b, c, x[k+10], S22, 0x2441453);
		c = GG(c, d, a, b, x[k+15], S23, 0xD8A1E681);
		b = GG(b, c, d, a, x[k+4],  S24, 0xE7D3FBC8);
		a = GG(a, b, c, d, x[k+9],  S21, 0x21E1CDE6);
		d = GG(d, a, b, c, x[k+14], S22, 0xC33707D6);
		c = GG(c, d, a, b, x[k+3],  S23, 0xF4D50D87);
		b = GG(b, c, d, a, x[k+8],  S24, 0x455A14ED);
		a = GG(a, b, c, d, x[k+13], S21, 0xA9E3E905);
		d = GG(d, a, b, c, x[k+2],  S22, 0xFCEFA3F8);
		c = GG(c, d, a, b, x[k+7],  S23, 0x676F02D9);
		b = GG(b, c, d, a, x[k+12], S24, 0x8D2A4C8A);
		a = HH(a, b, c, d, x[k+5],  S31, 0xFFFA3942);
		d = HH(d, a, b, c, x[k+8],  S32, 0x8771F681);
		c = HH(c, d, a, b, x[k+11], S33, 0x6D9D6122);
		b = HH(b, c, d, a, x[k+14], S34, 0xFDE5380C);
		a = HH(a, b, c, d, x[k+1],  S31, 0xA4BEEA44);
		d = HH(d, a, b, c, x[k+4],  S32, 0x4BDECFA9);
		c = HH(c, d, a, b, x[k+7],  S33, 0xF6BB4B60);
		b = HH(b, c, d, a, x[k+10], S34, 0xBEBFBC70);
		a = HH(a, b, c, d, x[k+13], S31, 0x289B7EC6);
		d = HH(d, a, b, c, x[k+0],  S32, 0xEAA127FA);
		c = HH(c, d, a, b, x[k+3],  S33, 0xD4EF3085);
		b = HH(b, c, d, a, x[k+6],  S34, 0x4881D05);
		a = HH(a, b, c, d, x[k+9],  S31, 0xD9D4D039);
		d = HH(d, a, b, c, x[k+12], S32, 0xE6DB99E5);
		c = HH(c, d, a, b, x[k+15], S33, 0x1FA27CF8);
		b = HH(b, c, d, a, x[k+2],  S34, 0xC4AC5665);
		a = II(a, b, c, d, x[k+0],  S41, 0xF4292244);
		d = II(d, a, b, c, x[k+7],  S42, 0x432AFF97);
		c = II(c, d, a, b, x[k+14], S43, 0xAB9423A7);
		b = II(b, c, d, a, x[k+5],  S44, 0xFC93A039);
		a = II(a, b, c, d, x[k+12], S41, 0x655B59C3);
		d = II(d, a, b, c, x[k+3],  S42, 0x8F0CCC92);
		c = II(c, d, a, b, x[k+10], S43, 0xFFEFF47D);
		b = II(b, c, d, a, x[k+1],  S44, 0x85845DD1);
		a = II(a, b, c, d, x[k+8],  S41, 0x6FA87E4F);
		d = II(d, a, b, c, x[k+15], S42, 0xFE2CE6E0);
		c = II(c, d, a, b, x[k+6],  S43, 0xA3014314);
		b = II(b, c, d, a, x[k+13], S44, 0x4E0811A1);
		a = II(a, b, c, d, x[k+4],  S41, 0xF7537E82);
		d = II(d, a, b, c, x[k+11], S42, 0xBD3AF235);
		c = II(c, d, a, b, x[k+2],  S43, 0x2AD7D2BB);
		b = II(b, c, d, a, x[k+9],  S44, 0xEB86D391);
		a = addUnsigned(a, AA);
		b = addUnsigned(b, BB);
		c = addUnsigned(c, CC);
		d = addUnsigned(d, DD);
	}
	var tempValue = wordToHex(a) + wordToHex(b) + wordToHex(c) + wordToHex(d);
	return tempValue.toLowerCase();
}


/*
 * 接收一个对象，给该对象添加sign属性
 */
function MD5Data(data){
	var message = "";
	for(var prop in data){
		message += (prop + data[prop]);
	}
	message += localStorage.getItem("loc_key");
	console.log("message: " + message);
	data.sign = MD5(message);
}


